@@ -5,21 +5,37 @@ from abc import ABC
 from copy import deepcopy
 from datetime import datetime
 from pathlib import Path
-from typing import Callable, Optional, Union, Dict, Any, Tuple, Union, cast, List, Sequence, TypeVar
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    TypeVar,
+    Union,
+    cast,
+)
 from warnings import warn
 
 import torch
-from torch import Tensor, ones, zeros
+from torch import Tensor
 from torch.utils.tensorboard import SummaryWriter
 
 import sbi.inference
 from sbi.inference.posterior import NeuralPosterior
 from sbi.simulators.simutils import simulate_in_batches
-from sbi.user_input.user_input_checks import prepare_for_sbi, process_x
-from sbi.utils import get_log_root, handle_invalid_x, warn_on_invalid_x
+from sbi.user_input.user_input_checks import prepare_for_sbi
+from sbi.utils import (
+    get_log_root,
+    handle_invalid_x,
+    warn_on_invalid_x,
+    warn_on_invalid_x_for_snpec_leakage,
+)
 from sbi.utils.plot import pairplot
-from sbi.utils.torchutils import configure_default_device
 from sbi.utils.sbiutils import get_data_since_round, mask_sims_from_prior
+from sbi.utils.torchutils import configure_default_device
 
 
 def infer(
@@ -64,7 +80,7 @@ def infer(
     simulator, prior = prepare_for_sbi(simulator, prior)
 
     infer_ = method_fun(simulator, prior, num_workers=num_workers)
-    posterior = infer_(num_rounds=1, num_simulations_per_round=num_simulations)
+    posterior = infer_(num_simulations=num_simulations)
 
     return posterior
 
@@ -140,6 +156,8 @@ class NeuralInference(ABC):
         # Initialize list that indicates the round from which simulations were drawn.
         self._data_round_index = []
 
+        self._round = 0
+
         # XXX We could instantiate here the Posterior for all children. Two problems:
         #     1. We must dispatch to right PotentialProvider for mcmc based on name
         #     2. `method_family` cannot be resolved only from `self.__class__.__name__`,
@@ -224,15 +242,20 @@ class NeuralInference(ABC):
         is_valid_x, num_nans, num_infs = handle_invalid_x(x, exclude_invalid_x)
         if warn_on_invalid:
             warn_on_invalid_x(num_nans, num_infs, exclude_invalid_x)
+            warn_on_invalid_x_for_snpec_leakage(
+                num_nans, num_infs, exclude_invalid_x, type(self).__name__, self._round
+            )
 
         return theta[is_valid_x], x[is_valid_x], prior_masks[is_valid_x]
 
-    def _run_simulations(self, round_: int, num_sims: int,) -> Tuple[Tensor, Tensor]:
+    def _run_simulations(
+        self, proposal: Optional[Any], num_sims: int,
+    ) -> Tuple[Tensor, Tensor]:
         r"""
         Run the simulations for a given round.
 
         Args:
-            round_: Round number.
+            proposal: Distribution from which to draw $\theta$.
             num_sims: Number of desired simulations for the round.
 
         Returns:
@@ -241,14 +264,10 @@ class NeuralInference(ABC):
             prior_mask: Whether each simulation came from a prior parameter sample.
         """
 
-        if round_ == 0:
+        if proposal is None:
             theta = self._prior.sample((num_sims,))
         else:
-            theta = self._posterior.sample(
-                (num_sims,),
-                x=self._posterior.default_x,
-                show_progress_bars=self._show_progress_bars,
-            )
+            theta = proposal.sample((num_sims,))
 
         x = self._batched_simulator(theta)
 
@@ -442,30 +461,40 @@ class NeuralInference(ABC):
     def summary(self):
         return self._summary
 
-    def _handle_x_o_wrt_amortization(
-        self, x_o: Optional[Tensor], x_shape: torch.Size, num_rounds: int
-    ) -> None:
+    def _check_proposal(self, proposal):
         """
-        Check whether provided `x_o` is consistent with `num_rounds`. For multi-round
-        inference, set `x_o` as the default observation in the posterior.
+        Check for validity of the provided proposal distribution.
 
-        Warns:
-            When `x_o` is provided, yet `num_rounds=1`, i.e. inference is amortized.
+        If the proposal is a `NeuralPosterior`, we check if the default_x is set and
+        if it matches the `_x_o_training_focused_on`.
 
-        Raises:
-            When `x_o` is absent, yet `num_rounds>1`, i.e. inference is focused.
+        If the proposal is **not** a `NeuralPosterior`, we warn. This is especially
+        important if the user passed the prior as proposal. Consider e.g.:
+        ```
+        posterior1 = infer(num_simulations=200, proposal=prior)
+        posterior2 = infer(num_simulations=200, proposal=prior)
+        ```
+        This will trigger atomic loss in the second line, which is not wanted.
         """
-
-        if num_rounds == 1 and x_o is not None:
-            warn("Providing `x_o` in a single-round scenario has no effect.")
-        elif num_rounds > 1 and x_o is None:
+        if proposal is not None:
+            if isinstance(proposal, NeuralPosterior):
+                if proposal.default_x is None:
+                    raise ValueError(
+                        "`proposal.default_x` is None, i.e. there is no "
+                        "x_o for training. Set it with "
+                        "`posterior.set_default_x(x_o)`."
+                    )
+            else:
+                warn(
+                    "The proposal you passed is not a `NeuralPosterior` object. If you "
+                    "are an expert user and did so for research purposes, this is fine."
+                    " If not, and you only wanted to do single round inference with"
+                    " `proposal=prior`, please instead set `proposal=None`, which"
+                    " automatically uses the prior as proposal."
+                )
+        elif self._round > 0:
             raise ValueError(
-                "Observed data `x_o` is required if `num_rounds>1` since "
-                "samples in all rounds after the first one are drawn from "
-                "the posterior `p(theta|x_o)`."
+                "You did not specify a proposal (i.e. `proposal=None`). "
+                "However, previously, you had already specified a proposal. "
+                "This scenario is currently not allowed."
             )
-
-        if num_rounds > 1:
-            processed_x = process_x(x_o, x_shape)
-            self._posterior._x_o_training_focused_on = processed_x
-            self._posterior.default_x = processed_x
